==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/ioverlaybase.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A base class for all 2D objects; includes basic functionality for working under
//  magnification. Can only be inherited.
//
#ifndef IOVERLAYBASE_H
#define IOVERLAYBASE_H


class iRenderTool;

class vtkCamera;
class vtkViewport;


class iOverlayBase
{

protected:
	
	iOverlayBase(const iRenderTool *rv);
	virtual ~iOverlayBase();
	
	inline const iRenderTool* GetRenderTool() const { return mRenderTool; }

	int GetRenderingMagnification() const;
	void ComputePositionShiftsUnderMagnification(vtkCamera *cam, int winij[2], vtkViewport *viewport);

	const iRenderTool *mRenderTool;
};

#endif // IOVERLAYBASE_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/ioverlaybase.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A base class for all 2D objects; includes basic functionality for working under
//  magnification. Can only be inherited.
//
#ifndef IOVERLAYBASE_H
#define IOVERLAYBASE_H


class iRenderTool;

class vtkCamera;
class vtkViewport;


class iOverlayBase
{

public:

	virtual void SetFontScale(int s);
	inline int GetFontScale(){ return mFontScale; }

protected:
	
	iOverlayBase(const iRenderTool *rv);
	virtual ~iOverlayBase();
	
	int GetFontSize(vtkViewport *vp, float factor = 1.0f) const;
	inline const iRenderTool* GetRenderTool() const { return mRenderTool; }

	vtkCamera* GetCamera(vtkViewport *viewport) const;
	int GetRenderingMagnification() const;
	void ComputePositionShiftsUnderMagnification(int winij[2]);

	const iRenderTool *mRenderTool;
	int mFontScale;
};

#endif // IOVERLAYBASE_H
